<?php

/*
To add support for a new site you will need to make 3 changes:

1. Edit $vl_sites to include the new site as an option in the admin.

2. Modify the switch statement in get_verse_url to call a new method you write, similar to the others, to format the url.

3. If the book names used within the urls for the site you are adding are different than the default, modify the switch
statement in customize_book_url_names() to override specific book names.
*/


// Step 1: Modify this to add a new site
$vl_sites = array("BelieversResource.com", "Bible.cc", "BibleGateway.com", "BibleStudyTools.com", "BlueLetterBible.org", "GodVine.com", "ScriptureText.com");


// Step 2: Add additional switch statement here to include a new site
function get_verse_url($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  if ($bookNumber==0) return "";

  switch(get_option('vl_preferred_website'))
  {
    case "Bible.cc":
      return get_verse_url_bible_cc($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber);
      break;
    case "BibleGateway.com":
      return get_verse_url_biblegateway_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber);
      break;
    case "BibleStudyTools.com":
      return get_verse_url_biblestudytools_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber);
      break;
    case "BlueLetterBible.org":
      return get_verse_url_blueletterbible_org($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber);
      break;
    case "GodVine.com":
      return get_verse_url_godvine_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber);
      break;
    case "ScriptureText.com":
      return get_verse_url_scripturetext_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber);
      break;
    default:
      return get_verse_url_believersresource_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber);
      break;
  }
}


// Step 3: If book names within the url are different than the default, modify the switch statement here when adding a new site.
function customize_book_url_names()
{
  global $bookUrlNames;
  switch(get_option('vl_preferred_website'))
  {
    case "Bible.cc":
    case "ScriptureText.com":
      $bookUrlNames[22]='songs';   
      break;
  }
}

function get_verse_url_believersresource_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  global $bookUrlNames;
  $result="http://www.believersresource.com/bible/" . $bookUrlNames[$bookNumber] . "-" . $chapterNumber . "-" . $verseNumber;
  if ($endVerseNumber>0)
  {
    if ($endChapternumber>0) $result .= "_" . $endChapterNumber . "-" . $endVerseNumber; else $result .= "_" . $endVerseNumber;
  }
  $result.=".html";
  return $result;
}


function get_verse_url_bible_cc($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  global $bookUrlNames;
  $result="http://www.bible.cc/bible/" . $bookUrlNames[$bookNumber] . "/" . $chapterNumber . "-" . $verseNumber . ".htm";
  if ($endVerseNumber>0) $result="";   //does not support ranges
  return $result;
}

function get_verse_url_biblegateway_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  global $bookUrlNames;
  $result="http://www.biblegateway.com/passage/?search=" . str_replace("_","+", $bookUrlNames[$bookNumber]) . "+" . $chapterNumber . ":" . $verseNumber;
  if ($endVerseNumber>0)
  {
    if ($endChapternumber>0) $result .= "-" . $endChapterNumber . ":" . $endVerseNumber; else $result .= "-" . $endVerseNumber;
  }
  return $result;
}

function get_verse_url_biblestudytools_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  global $bookUrlNames;
  $result="http://www.biblestudytools.com/" . str_replace("_","-", $bookUrlNames[$bookNumber]) . "/" . $chapterNumber . "-" . $verseNumber . ".html";
  if ($endVerseNumber>0) {
      if ($endChapterNumber>0) $result=""; else $result="http://www.biblestudytools.com/passage.aspx?q=" . str_replace("_","-", $bookUrlNames[$bookNumber]) . "+" . $chapterNumber . ":" . $verseNumber . "-" . $endVerseNumber;
  }
  return $result;
}

function get_verse_url_blueletterbible_org($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  global $bookUrlNames;
  $result="http://www.blueletterbible.org/Bible.cfm?b=" . str_replace("_","+", $bookUrlNames[$bookNumber]) . "&c=" . $chapterNumber . "#comm/" . $verseNumber;
  if ($endVerseNumber>0) $result="";   //does not support ranges
  return $result;
}

function get_verse_url_godvine_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  global $bookUrlNames;
  $result="http://www.godvine.com/bible/" . str_replace("_","-", $bookUrlNames[$bookNumber]) . "/" . $chapterNumber . "-" . $verseNumber;
  if ($endVerseNumber>0) $result="";   //does not support ranges
  return $result;
}

function get_verse_url_scripturetext_com($bookNumber, $chapterNumber, $verseNumber, $endChapterNumber, $endVerseNumber)
{
  global $bookUrlNames;
  $result="http://www.scripturetext.com/" . str_replace("_","-", $bookUrlNames[$bookNumber]) . "/" . $chapterNumber . "-" . $verseNumber . ".htm";
  if ($endVerseNumber>0) $result="";   //does not support ranges
  return $result;
}

?>